@@ -76,9 +76,9 @@ class BillInvoices(Resource):
                         "vendor_id": payload.get("vendor_id", "")
                     })
 
-                if 'invoice_number' in payload.keys():
+                if 'vendor_invoice_no' in payload.keys():
                     data.update({
-                        "bill_number": payload.get("invoice_number", super().generate_code())
+                        "bill_number": payload.get("vendor_invoice_no", "")
                     })
 
                 if 'reference' in payload.keys():
@@ -86,6 +86,11 @@ class BillInvoices(Resource):
                         "reference_number": payload.get("reference", super().generate_code())
                     })
 
+                if 'date' in payload.keys():
+                    data.update({
+                        "date": payload.get("date", '')
+                    })
+
                 if 'due_date' in payload.keys():
                     data.update({
                         "due_date": payload.get("due_date", '')
@@ -94,8 +99,8 @@ class BillInvoices(Resource):
                 line_items = payload.get("line_items", [])
 
                 for i in range(len(line_items)):
-                    if "item_ledger_id" in line_items[i].keys():
-                        line_items[i]["item_id"] = line_items[i].pop("item_ledger_id")
+                    if "item_id" in line_items[i].keys():
+                        line_items[i]["item_id"] = line_items[i].pop("item_id")
                     if "price" in line_items[i].keys():
                         line_items[i]["rate"] = line_items[i].pop("price")
                     if "quantity" in line_items[i].keys():
@@ -115,9 +120,7 @@ class BillInvoices(Resource):
                         line_items[i].pop("tax_id")
                     if 'account_id' in line_items[i].keys():
                         line_items[i].pop("account_id")
-                
-                if 'item_id' in payload.keys():
-                    payload.pop("item_id") 
+                        
                 if 'currency_code' in payload.keys():
                     payload.pop("currency_code")  
                 if 'amount' in payload.keys():
@@ -161,8 +164,8 @@ class BillInvoices(Resource):
 
                     if "type" in line_items[i].keys():
                         line_items[i].pop("type")
-                    if "item_ledger_id" in line_items[i].keys():
-                        line_items[i].pop("item_ledger_id")
+                    if "item_id" in line_items[i].keys():
+                        line_items[i].pop("item_id")
                     if "unit_of_measure" in line_items[i].keys():
                         line_items[i].pop("unit_of_measure")
                     if "quantity" in line_items[i].keys():
@@ -184,9 +187,7 @@ class BillInvoices(Resource):
                     "vendor_invoice_no": f'{payload.get("vendor_invoice_no", "")}',
                     "due_date": f'{payload.get("due_date", "")}',
                 })
-
-                if "item_id" in payload.keys():
-                    payload.pop("item_id")
+                
                 if "currency_code" in payload.keys():
                     payload.pop("currency_code")
                 if "amount" in payload.keys():
@@ -195,9 +196,9 @@ class BillInvoices(Resource):
                 line_items = payload.get("line_items", [])
 
                 for i in range(len(line_items)):
-                    if "item_ledger_id" in line_items[i].keys():
+                    if "item_id" in line_items[i].keys():
                         line_items[i]["item_id"] = line_items[i].pop(
-                            "item_ledger_id"
+                            "item_id"
                         )
                     if "quantity" in line_items[i].keys():
                         line_items[i]["quantity"] = line_items[i].pop("quantity")
