@@ -174,28 +174,73 @@ class BillPayments(Resource):
                         "amount": payload.get("amount", "")
                     })
 
-                if 'reference' in payload.keys():
-                    data.update({
-                        "reference": payload.get("reference", "")
-                    })
+                # if 'reference' in payload.keys():
+                #     data.update({
+                #         "reference": payload.get("reference", "")
+                #     })
 
                 if 'date' in payload.keys():
                     data.update({
                         "date": payload.get("date", "")
                     })
+                
+                invoices = payload.get("invoice_payments", [])
+
+                for i in range(len(invoices)): 
+                    if i == 0:
+                        if 'reference' in invoices[i].keys():
+                            data.update({
+                                "reference_number": invoices[i].pop('reference')
+                            })
+                        if 'account_id' in invoices[i].keys():
+                            data.update({
+                                "paid_through_account_id": invoices[i].pop('account_id')
+                            })
+                    
+                    if 'invoice_id' in invoices[i].keys():
+                        invoices[i]['bill_id'] = invoices[i].pop('invoice_id')
+                    if 'amount' in invoices[i].keys():
+                        invoices[i]['amount_applied'] = invoices[i].pop('amount')
+                            
+                    if 'payment_date' in invoices[i].keys():
+                        invoices[i].pop('payment_date')                            
+                    if 'payment_type' in invoices[i].keys():
+                        invoices[i].pop('payment_type')
 
             # If client type is MS_DYNAMICS
             elif super().get_client_type() == super().MS_DYNAMICS:
                 data.pop("type")
                 data.update({
-                    "paymentReference": payload.get("reference", ""),
+                    # "paymentReference": payload.get("reference", ""),
                     "ownerInvoiceType": "Vendor",
-                    "ownerInvoiceNumber": payload.get("invoice_id", ""),
+                    # "ownerInvoiceNumber": payload.get("invoice_id", ""),
                     "ownerNumber": payload.get("vendor_id", ""),
                     "description": payload.get("description", ""),
-                    "amount": payload.get("amount", 0),
+                    # "amount": payload.get("amount", 0),
                     "bankCode": payload.get("bank_code", ""),
                 })
+                invoice = payload.get("invoice_payments", [])
+
+                if bool(invoice):
+                    if "invoice_id" in invoice[0].keys():
+                        data.update({
+                            "ownerInvoiceNumber": invoice[0].pop("invoice_id"),
+                        }) 
+                    if 'reference' in invoice[0].keys():
+                        data.update({
+                            "paymentReference": invoice[0].pop('reference')
+                        })
+                    if 'amount' in invoice[0].keys():
+                        data.update({
+                            "amount": invoice[0].pop('amount')
+                        })                    
+                    
+                    if 'payment_date' in invoice[0].keys():
+                        invoice[0].pop('payment_date')
+                    if 'payment_type' in invoice[0].keys():
+                        invoice[0].pop('payment_type')
+                    if 'account_id' in invoice[0].keys():
+                        invoice[0].pop('account_id')
 
             data.update(additional_properties)
 
