@@ -119,6 +119,23 @@ class Currencies(Resource):
                 if 'AccountCode' in additional_properties.keys():
                     additional_properties.pop("AccountCode")
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                if 'currency_code' in payload.keys():
+                    data.update({
+                        "name": payload.get("currency_code", "")
+                    })
+                
+                if 'currency_name' in payload.keys():
+                    data.update({
+                        "display_name": payload.get("currency_name", "")
+                    })
+                
+                if 'currency_symbol' in payload.keys():
+                    data.update({
+                        "symbol": payload.get("currency_symbol", "")
+                    })
+
             data.update(additional_properties)
 
             return data
