@@ -218,10 +218,10 @@ class Customer(Resource):
 
                 contact_persons = {}
 
-                if 'type' in payload.keys():
-                    data.update({
-                        "contact_type": payload.get("type", "customer")
-                    })
+                data.update({
+                    "contact_type": payload.get("type", "customer"),
+                    "customer_sub_type": "business",
+                })
 
                 if 'title' in payload.keys():
                     data.update({
